-- ----------------------------
-- 1、部门表
-- ----------------------------
drop table if exists sys_dept;
create table sys_dept (
  dept_id           bigint(20)      not null auto_increment    comment '部门id',
  parent_id         bigint(20)      default 0                  comment '父部门id',
  ancestors         varchar(50)     default ''                 comment '祖级列表',
  dept_name         varchar(30)     default ''                 comment '部门名称',
  order_num         int(4)          default 0                  comment '显示顺序',
  leader            varchar(20)     default null               comment '负责人',
  phone             varchar(11)     default null               comment '联系电话',
  email             varchar(50)     default null               comment '邮箱',
  status            char(1)         default '0'                comment '部门状态（0正常 1停用）',
  del_flag          char(1)         default '0'                comment '删除标志（0代表存在 2代表删除）',
  create_by         varchar(64)     default ''                 comment '创建者',
  create_time 	    datetime                                   comment '创建时间',
  update_by         varchar(64)     default ''                 comment '更新者',
  update_time       datetime                                   comment '更新时间',
  primary key (dept_id)
) engine=innodb auto_increment=200 comment = '部门表';

-- ----------------------------
-- 初始化-部门表数据
-- ----------------------------
INSERT INTO sys_dept VALUES (100, 0, '0', '四川中水成勘院测绘工程有限责任公司', 0, NULL, NULL, NULL, '0', '0', 'admin', '2024-01-04 11:34:52', NULL, NULL);
INSERT INTO sys_dept VALUES (101, 100, '0,100', '董事会', 1, NULL, NULL, NULL, '0', '0', 'admin', '2024-01-04 11:34:52', NULL, NULL);
INSERT INTO sys_dept VALUES (102, 100, '0,100', '经营管理层', 2, NULL, NULL, NULL, '0', '0', 'admin', '2024-01-04 11:36:52', NULL, NULL);
INSERT INTO sys_dept VALUES (103, 100, '0,100', '综合事务部', 3, NULL, NULL, NULL, '0', '0', 'admin', '2024-01-04 11:38:16', NULL, NULL);
INSERT INTO sys_dept VALUES (104, 100, '0,100', '经营发展部', 4, NULL, NULL, NULL, '0', '0', 'admin', '2024-01-04 11:38:32', NULL, NULL);
INSERT INTO sys_dept VALUES (105, 100, '0,100', '财务部', 5, NULL, NULL, NULL, '0', '0', 'admin', '2024-01-04 11:38:44', NULL, NULL);
INSERT INTO sys_dept VALUES (106, 100, '0,100', '项目管理部', 6, NULL, NULL, NULL, '0', '0', 'admin', '2024-01-04 11:39:02', NULL, NULL);
INSERT INTO sys_dept VALUES (107, 100, '0,100', '激光技术中心', 7, NULL, NULL, NULL, '0', '0', 'admin', '2024-01-04 11:39:21', NULL, NULL);
INSERT INTO sys_dept VALUES (108, 100, '0,100', '地理信息中心', 8, NULL, NULL, NULL, '0', '0', 'admin', '2024-01-04 11:39:31', NULL, NULL);
INSERT INTO sys_dept VALUES (109, 100, '0,100', '技术质量部', 9, NULL, NULL, NULL, '0', '0', 'admin', '2024-01-04 11:39:50', NULL, NULL);
INSERT INTO sys_dept VALUES (110, 100, '0,100', '航测遥感中心', 10, NULL, NULL, NULL, '0', '0', 'admin', '2024-01-04 11:40:03', NULL, NULL);
INSERT INTO sys_dept VALUES (111, 100, '0,100', '测绘工程中心', 11, NULL, NULL, NULL, '0', '0', 'admin', '2024-01-04 11:40:16', NULL, NULL);
INSERT INTO sys_dept VALUES (112, 100, '0,100', '工程监测中心', 12, NULL, NULL, NULL, '0', '0', 'admin', '2024-01-04 11:40:35', NULL, NULL);
INSERT INTO sys_dept VALUES (113, 100, '0,100', '勘察设计事业部', 13, NULL, NULL, NULL, '0', '0', 'admin', '2024-01-04 11:40:59', NULL, NULL);
INSERT INTO sys_dept VALUES (114, 100, '0,100', '测量中心', 14, NULL, NULL, NULL, '0', '0', 'admin', '2024-01-04 11:41:14', NULL, NULL);
INSERT INTO sys_dept VALUES (115, 100, '0,100', '重庆分公司', 15, NULL, NULL, NULL, '0', '0', 'admin', '2024-01-04 11:42:31', NULL, NULL);
INSERT INTO sys_dept VALUES (116, 100, '0,100', '德方子公司', 16, NULL, NULL, NULL, '0', '0', 'admin', '2024-01-04 11:42:56', NULL, NULL);
INSERT INTO sys_dept VALUES (117, 100, '0,100', '云南子公司', 17, NULL, NULL, NULL, '0', '0', 'admin', '2024-01-04 11:43:16', NULL, NULL);

-- ----------------------------
-- 2、用户信息表
-- ----------------------------
drop table if exists sys_user;
create table sys_user (
  user_id           bigint(20)      not null auto_increment    comment '用户ID',
  dept_id           bigint(20)      default null               comment '部门ID',
  user_name         varchar(30)     not null                   comment '用户账号',
  nick_name         varchar(30)     not null                   comment '用户昵称',
  user_type         varchar(2)      default '00'               comment '用户类型（00系统用户）',
  email             varchar(50)     default ''                 comment '用户邮箱',
  phonenumber       varchar(11)     default ''                 comment '手机号码',
  sex               char(1)         default '0'                comment '用户性别（0男 1女 2未知）',
  avatar            varchar(100)    default ''                 comment '头像地址',
  password          varchar(100)    default ''                 comment '密码',
  status            char(1)         default '0'                comment '帐号状态（0正常 1停用）',
  del_flag          char(1)         default '0'                comment '删除标志（0代表存在 2代表删除）',
  login_ip          varchar(128)    default ''                 comment '最后登录IP',
  login_date        datetime                                   comment '最后登录时间',
  create_by         varchar(64)     default ''                 comment '创建者',
  create_time       datetime                                   comment '创建时间',
  update_by         varchar(64)     default ''                 comment '更新者',
  update_time       datetime                                   comment '更新时间',
  remark            varchar(500)    default null               comment '备注（作业类别）',
  pm_level			char(1)			default null			   comment '项目经理级别（0一、1二、2三）',
  titles			char(1)			default null			   comment '技术职称（0正高、1副高、2中级、3助工、4注测、5注规、6注岩、7注安、8注会）',
  engineer_level	char(1)			default null			   comment '岗级（0二、1三、2四、3五、4六）',
  entry_date		datetime								   comment '入职时间',
  age				int				default null			   comment '年龄',
  primary key (user_id)
) engine=innodb auto_increment=1 comment = '用户信息表';

-- ----------------------------
-- 初始化-用户信息表数据
-- ----------------------------
INSERT INTO sys_user VALUES (1, 103, 'admin', 'admin', '00', '', 'admin', '1', '', '$2a$10$7JB720yubVSZvUI0rEqK/.VqGOZTH.ulu33dHOiBE8ByOhJIrdAu2', '0', '0', '127.0.0.1', '2024-01-08 10:07:29', NULL, '2024-01-04 17:22:48', NULL, '2024-01-08 10:07:29', '管理员', NULL, NULL, NULL, NULL, NULL);
INSERT INTO sys_user VALUES (2, 101, '13982275233', '刘光庆', '00', '', '13982275233', '0', '', '$2a$10$pcdc8BbNDNiWaQUU14BC3eGWxB4sSJOQZBL9QFftkhkjcbYU03DNi', '0', '0', '', NULL, NULL, '2024-01-04 17:22:48', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO sys_user VALUES (3, 101, '13808211356', '向发廷', '00', '', '13808211356', '0', '', '$2a$10$zynAhjpaUxERmH4yo9R9s.O.oUgpxwRKtKA6X74ncn0z1ajFxqMyq', '0', '0', '', NULL, NULL, '2024-01-04 17:22:48', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO sys_user VALUES (4, 101, '13608089391', '王 渊', '00', '', '13608089391', '0', '', '$2a$10$sKWfjdS0vJMA194/pu9q/e8Etz6kNBTzlURGDtKreBE8oHsRWP9hW', '0', '0', '', NULL, NULL, '2024-01-04 17:22:48', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO sys_user VALUES (5, 101, '13808210959', '饶兴贵', '00', '', '13808210959', '0', '', '$2a$10$oyppe5szUKvS7tmJGPEMAOokXiWFJys5MMfOWFc6.ETpyBgCDo/42', '0', '0', '', NULL, NULL, '2024-01-04 17:22:48', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO sys_user VALUES (6, 101, '13308085432', '阴学军', '00', '', '13308085432', '0', '', '$2a$10$nb/NapsXWQd/IfPbrqXKjefXlOKmRB5ScgVneGxPgEyo4FZ8.RMOi', '0', '0', '', NULL, NULL, '2024-01-04 17:22:48', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO sys_user VALUES (7, 101, '13908178105', '樊宽林', '00', '', '13908178105', '0', '', '$2a$10$wnFsEXdHdJCgVYffXW7FRerg0c3v3S.aVqtdiWrtSAt9KntmW6iIu', '0', '0', '', NULL, NULL, '2024-01-04 17:22:48', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO sys_user VALUES (8, 103, '18034708068', '徐 婷', '00', '', '18034708068', '1', '', '$2a$10$3NJkNMrq0/vwnw5E3z6wI.TutQnqhwSuMFDPxV/OMe9IXt0fTobNW', '0', '0', '', NULL, NULL, '2024-01-04 17:22:48', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO sys_user VALUES (9, 102, '13880963113', '陈 洪', '00', '', '13880963113', '0', '', '$2a$10$xVZmDdG0DUlGjuGMFi6WEem4pWuLKlqrg27VuBRbn3vfKq8ATWzVa', '0', '0', '', NULL, NULL, '2024-01-04 17:22:48', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO sys_user VALUES (10, 102, '13981868188', '刘 非', '00', '', '13981868188', '0', '', '$2a$10$XCXSEHjvWp9IFbQIXfh/gu5i8R87DjKMHsEu.qioLaZLVDB3wr1z2', '0', '0', '', NULL, NULL, '2024-01-04 17:22:48', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO sys_user VALUES (11, 102, '13882236733', '杨 卫', '00', '', '13882236733', '0', '', '$2a$10$buRf8Vh0f4./GVx9WV6zkO1LOKSIEnTK4tzXefEh6gcY2JfcI4gPO', '0', '0', '', NULL, NULL, '2024-01-04 17:22:48', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO sys_user VALUES (12, 102, '13980583883', '宁 瑶', '00', '', '13980583883', '0', '', '$2a$10$srx9flT57EE/f2euaLgrIeud6Ujnz3HS3qfNYm7DXFY6XZ5p5Aai2', '0', '0', '', NULL, NULL, '2024-01-04 17:22:48', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO sys_user VALUES (13, 104, '18190819097', '贾春华', '00', '', '18190819097', '0', '', '$2a$10$QSI1Pl1YK6kGt0zLDNv1COQyK8UDLWhBq26QSXEPpikIDArtqjeau', '0', '0', '', NULL, NULL, '2024-01-04 17:22:48', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO sys_user VALUES (14, 105, '15928150405', '刘 楠', '00', '', '15928150405', '0', '', '$2a$10$6tmHn6r5Dy6/qdu/ZotiSObzEr7zymkKL/g/VkcdUjV16OezZFALu', '0', '0', '', NULL, NULL, '2024-01-04 17:22:48', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO sys_user VALUES (15, 103, '13678018998', '张明勇', '00', '', '13678018998', '0', '', '$2a$10$TKhy.bdUf4CmSN4nnVGZIeuQvtaFc1V/cXKT87sCjpOwvLOGpDuC.', '0', '0', '', NULL, NULL, '2024-01-04 17:22:48', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO sys_user VALUES (16, 103, '13683488600', '陈建贤', '00', '', '13683488600', '0', '', '$2a$10$/2zL9VLX21iPxTVPklI11uOanp0bcR90mgCc9tIz6.Ux1/tegzFBG', '0', '0', '', NULL, NULL, '2024-01-04 17:22:48', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO sys_user VALUES (17, 103, '13438165216', '张国芳', '00', '', '13438165216', '1', '', '$2a$10$sKkER/2RwOhIcufS8ceg..D9TchtO/R4nFCP1cDpW4BsS47TcqqRC', '0', '0', '', NULL, NULL, '2024-01-04 17:22:48', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO sys_user VALUES (18, 103, '15181125323', '简   鑫', '00', '', '15181125323', '1', '', '$2a$10$v2mVQvW5BsZnrxJ6j.AHRebGVQMRI3jaDlX0lDQnpBD.Y86VSnf9K', '0', '0', '', NULL, NULL, '2024-01-04 17:22:48', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO sys_user VALUES (19, 103, '13378256139', '谢辉波', '00', '', '13378256139', '0', '', '$2a$10$mZT.3thlsNmtiGXrgJxIm.QbktUAa9blLqwOq7LhGfy1XG1xnAzEm', '0', '0', '', NULL, NULL, '2024-01-04 17:22:48', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO sys_user VALUES (20, 104, '13550342375', '李胜才', '00', '', '13550342375', '0', '', '$2a$10$lUhqpfwHzoVXPDC6qRu8su8HWlLJ49SCEo1NDXyFf2q5C8hThZbXi', '0', '0', '', NULL, NULL, '2024-01-04 17:22:48', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO sys_user VALUES (21, 104, '13568885428', '杨   俊', '00', '', '13568885428', '0', '', '$2a$10$CSpKNIxy1hlgONyLZNk9hupaQXiwpGEJYv8DFcSebuIp81J6aheeO', '0', '0', '', NULL, NULL, '2024-01-04 17:22:48', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO sys_user VALUES (22, 104, '13882200825', '夏   夏', '00', '', '13882200825', '0', '', '$2a$10$WMD98fLsImPZ9rJwyIely.j5AKiQyUt/I3qT/Xcg5EdQCIkxx4kq2', '0', '0', '', NULL, NULL, '2024-01-04 17:22:48', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO sys_user VALUES (23, 104, '18373705527', '柯   枭', '00', '', '18373705527', '1', '', '$2a$10$EMikBVL2M4b97n.MJmMCNO1YiFl49bjWWXZkFDZqvVkOpYhb5FEe6', '0', '0', '', NULL, NULL, '2024-01-04 17:22:48', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO sys_user VALUES (24, 104, '18202833529', '黎   超', '00', '', '18202833529', '0', '', '$2a$10$MkPiNt69sG3HQg9EY3cpv.0Sw1iq53NMq/kdplK9W8ohqqY/dlUxC', '0', '0', '', NULL, NULL, '2024-01-04 17:22:48', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO sys_user VALUES (25, 104, '13111885671', '刘   兴', '00', '', '13111885671', '0', '', '$2a$10$Ag2jfz8ppoSP4bpohVVD1evq8glP6O4tY0HD9DoXXhsPpxSP8egSy', '0', '0', '', NULL, NULL, '2024-01-04 17:22:48', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO sys_user VALUES (26, 104, '18782949671', '梁   洁', '00', '', '18782949671', '1', '', '$2a$10$BZurM7Hzy/aquuAlLkk/pOD.y0Ks.BtYcCTTyEwtJHY3QEgFdwRBe', '0', '0', '', NULL, NULL, '2024-01-04 17:22:48', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO sys_user VALUES (27, 104, '18681251027', '高天沄', '00', '', '18681251027', '0', '', '$2a$10$xk96PJpjcUIWEo9RTTOKYubqeSXETSUSbRYFjpCgSr1z9PPKUSKsu', '0', '0', '', NULL, NULL, '2024-01-04 17:22:48', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO sys_user VALUES (28, 105, '18202802155', '彭   敏', '00', '', '18202802155', '1', '', '$2a$10$ozjePPQbsp9YORLj7r4.K.lTC/9E/ANgDsOHsEyHlQ9DP2MtggiAO', '0', '0', '', NULL, NULL, '2024-01-04 17:22:48', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO sys_user VALUES (29, 105, '13699682119', '苟   丹', '00', '', '13699682119', '1', '', '$2a$10$Jt.lg9CXVwlm0puSYFS6IOjxrSPAAHuf5gFmRtRX89IAwJlL8bm4e', '0', '0', '', NULL, NULL, '2024-01-04 17:22:48', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO sys_user VALUES (30, 105, '18780223280', '周文婷*', '00', '', '18780223280', '1', '', '$2a$10$pg.prMidA.76KkPRsZsOQuKStpl74J29heNpxCtJbZqDl7i9DjIuu', '0', '0', '', NULL, NULL, '2024-01-04 17:22:48', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO sys_user VALUES (31, 105, '15102831685', '宋丹丹', '00', '', '15102831685', '1', '', '$2a$10$/j4MpWKxCUekgxiTD1yyyOpOVJme5YbfJz042FuNJLuccxkC2yJSm', '0', '0', '', NULL, NULL, '2024-01-04 17:22:48', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO sys_user VALUES (32, 106, '15802829286', '向艳雄', '00', '', '15802829286', '0', '', '$2a$10$FQo1zf1ss2OZw4eIlzzxwOyPV0FkkLDN0ZBxqRSIijNpUCCSxBjQy', '0', '0', '', NULL, NULL, '2024-01-04 17:22:48', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO sys_user VALUES (33, 106, '18828096127', '朱   静', '00', '', '18828096127', '0', '', '$2a$10$PrXuWRk4u9d05TNI9MAGjeGwmsSglOtGNKX.fjDuRwmTfVSFr4x9C', '0', '0', '', NULL, NULL, '2024-01-04 17:22:48', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO sys_user VALUES (34, 106, '13882148315', '陈尚云', '00', '', '13882148315', '0', '', '$2a$10$I7CDnjCXqmbFmxdgcsoZ/uhgvEahRGZ/u3P4bdIU1Kic49Itu97JG', '0', '0', '', NULL, NULL, '2024-01-04 17:22:48', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO sys_user VALUES (35, 106, '18113169528', '蒲   帆', '00', '', '18113169528', '0', '', '$2a$10$Z.3Y46kvgMCHpVSsXl3WJO4OOLJhr5IlzXTQqWx1a8yR1HaJQJQQW', '0', '0', '', NULL, NULL, '2024-01-04 17:22:48', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO sys_user VALUES (36, 106, '18408201550', '邹帅民', '00', '', '18408201550', '0', '', '$2a$10$VC/JGLy.P6yJ5LJHmuq2dur.wnHYDzzxjyaizC8fYVNRq5DBmjjIm', '0', '0', '', NULL, NULL, '2024-01-04 17:22:48', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO sys_user VALUES (37, 106, '13808178930', '周   芝', '00', '', '13808178930', '1', '', '$2a$10$4SuEJ.5YZSnk3UlpISWBmer7UZVMBKuMNBiG2/lUKafwNr1jI1UF2', '0', '0', '', NULL, NULL, '2024-01-04 17:22:48', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO sys_user VALUES (38, 106, '18780290087', '苟   旭', '00', '', '18780290087', '0', '', '$2a$10$QCU/ERPaKSs5CAuWWB2WZ.13fxht6GKgGORCBS8DUy3qBmJybgzM.', '0', '0', '', NULL, NULL, '2024-01-04 17:22:48', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO sys_user VALUES (39, 107, '18280462009', '刘媛媛', '00', '', '18280462009', '1', '', '$2a$10$SWNBLt43nQQJPC58DZmZcuHqkhre8lOMfl87AnM5UKuMrMfuPpaO6', '0', '0', '', NULL, NULL, '2024-01-04 17:22:48', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO sys_user VALUES (40, 107, '18200194440', '吴   振', '00', '', '18200194440', '0', '', '$2a$10$a3ozNbqM6BYYISEJGIpx5O83L1RpMXNc4A9gpPu93qZ9PahUzx24u', '0', '0', '', NULL, NULL, '2024-01-04 17:22:48', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO sys_user VALUES (41, 107, '15892280776', '王   刚', '00', '', '15892280776', '0', '', '$2a$10$ulhCOUUylhfnX7iccme6I.zpwLdnvU3zXXuMJ9LtRILnviD6Pvg9u', '0', '0', '', NULL, NULL, '2024-01-04 17:22:48', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO sys_user VALUES (42, 107, '18140026972', '朱倪强', '00', '', '18140026972', '0', '', '$2a$10$HLRPkMz/orRnHouLjKNoH.Mn..dH97urH6up1x5AO0ZmtL64wp5XG', '0', '0', '', NULL, NULL, '2024-01-04 17:22:48', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO sys_user VALUES (43, 107, '18408248664', '李   圆', '00', '', '18408248664', '1', '', '$2a$10$nMUdzmsF1Tk1FOR7k92kMulRN31LkiWV45F3eAAvNwCS8acu9endK', '0', '0', '', NULL, NULL, '2024-01-04 17:22:48', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO sys_user VALUES (44, 107, '18783205676', '李泳龙', '00', '', '18783205676', '0', '', '$2a$10$LHQQe3UHQgaJDCnPl.gujuBKgRhrMN88kPKRxev2HSvOrV2IDRAfG', '0', '0', '', NULL, NULL, '2024-01-04 17:22:48', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO sys_user VALUES (45, 108, '13402863790', '何   杰', '00', '', '13402863790', '0', '', '$2a$10$XZhKTnoYh.zS/TczIVjJyOVMvwjQ.fiH3QtTpB9M2OaHnhpIiOYWS', '0', '0', '', NULL, NULL, '2024-01-04 17:22:48', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO sys_user VALUES (46, 108, '18224091291', '杨玉婧', '00', '', '18224091291', '1', '', '$2a$10$goGcN9K63wIO7t8Rkw95kuMb1twHzRU51Dk6q31/.Hejl2Aro0kVq', '0', '0', '', NULL, NULL, '2024-01-04 17:22:48', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO sys_user VALUES (47, 108, '15196615885', '余思翰', '00', '', '15196615885', '1', '', '$2a$10$IjogDx43u3xmI2TigAo6CugCKh.AAmwOSf1nKBCWlJ/cEhgpX.H3e', '0', '0', '', NULL, NULL, '2024-01-04 17:22:48', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO sys_user VALUES (48, 108, '17716873691', '阮梦妍', '00', '', '17716873691', '1', '', '$2a$10$XXlN3NzrRMBmMudrV3ZgOOtEq.RML/KrrVhN/uh.rpP7chAqy8QTe', '0', '0', '', NULL, NULL, '2024-01-04 17:22:48', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO sys_user VALUES (49, 108, '15881196342', '赵   芩', '00', '', '15881196342', '1', '', '$2a$10$x2pMljHso1uFHnjDpFu0/OPGrU1ITvl7hnv/bwFFQVUIH/mQ39k2G', '0', '0', '', NULL, NULL, '2024-01-04 17:22:48', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO sys_user VALUES (50, 108, '18502889383', '王荣华', '00', '', '18502889383', '0', '', '$2a$10$G7uXmOzRgagbI2jske8meuu8p0QgvTvMxLDzV0gQWHVaKJTsW6e3i', '0', '0', '', NULL, NULL, '2024-01-04 17:22:48', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO sys_user VALUES (51, 108, '19982093641', '屈亚星', '00', '', '19982093641', '1', '', '$2a$10$gklMWtGS2E8tdWakJpNk9OyEv2g/2MGuQupEH0Q7zCpZI9XJPMxyC', '0', '0', '', NULL, NULL, '2024-01-04 17:22:48', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO sys_user VALUES (52, 109, '13880509805', '吴   凯', '00', '', '13880509805', '0', '', '$2a$10$AN5g8asAyLLW9.POKvkh8.WPCKqzf4Ze71ltLA.wIbEqIH3fQSj0q', '0', '0', '', NULL, NULL, '2024-01-04 17:22:48', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO sys_user VALUES (53, 109, '13981911565', '李   旭', '00', '', '13981911565', '0', '', '$2a$10$j4GUGW8LwJVW5kS98xis3.PYbeMsqjJwiJBnmj1lYpS04hqp7IvMi', '0', '0', '', NULL, NULL, '2024-01-04 17:22:48', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO sys_user VALUES (54, 109, '13708077449', '马如坤', '00', '', '13708077449', '0', '', '$2a$10$SO9HTWCXPMBbHiMUs73YdON7RYGfi0LbB/Tfyq5e7BZaxSbJvTB3S', '0', '0', '', NULL, NULL, '2024-01-04 17:22:48', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO sys_user VALUES (55, 109, '13684088875', '张   进', '00', '', '13684088875', '0', '', '$2a$10$TMJoxh5FamkqFR7crz.eh.1/jwx9JdyAm9SAE/wzZdwgzfqjljvGC', '0', '0', '', NULL, NULL, '2024-01-04 17:22:48', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO sys_user VALUES (56, 109, '13550225550', '冉洪芳', '00', '', '13550225550', '1', '', '$2a$10$N0iuZU3JhPqLBogqtMbmeuL1aGb/D3E0Yh3UUoJX6yV.iaVT1WBhq', '0', '0', '', NULL, NULL, '2024-01-04 17:22:48', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO sys_user VALUES (57, 109, '13880738350', '周文婷', '00', '', '13880738350', '1', '', '$2a$10$Z8hiF47EMxhCXq9I/xbLbuJloSnoARKeiRgodgBcer7lq1VsYE3fC', '0', '0', '', NULL, NULL, '2024-01-04 17:22:48', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO sys_user VALUES (58, 109, '13558636992', '谭   君', '00', '', '13558636992', '1', '', '$2a$10$uBsL6WPQpYCbT0oddsoll.VrLlMDrRWU2my.VdnNovu9c.thOXR1e', '0', '0', '', NULL, NULL, '2024-01-04 17:22:48', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO sys_user VALUES (59, 109, '13658078979', '王晶丽', '00', '', '13658078979', '1', '', '$2a$10$PBNCy8SQPudxBTigEEXVAuIot2PoUDMz6KV1u8TeXBvXiS0CAUMtW', '0', '0', '', NULL, NULL, '2024-01-04 17:22:48', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO sys_user VALUES (60, 109, '13488986700', '罗业华', '00', '', '13488986700', '0', '', '$2a$10$8np5PzaPEkMQwRYUzSnUX.pDQSRdbpFXyzhtYvBj11OzTaNmGAEtG', '0', '0', '', NULL, NULL, '2024-01-04 17:22:48', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO sys_user VALUES (61, 109, '13540297596', '郎悟灵', '00', '', '13540297596', '1', '', '$2a$10$BU3usTExEEbFa7VGIbnOgeAJ3CsJXPkzV6ZTH2xRtu70Es76RP5j.', '0', '0', '', NULL, NULL, '2024-01-04 17:22:48', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO sys_user VALUES (62, 109, '18030862435', '黄俊峰', '00', '', '18030862435', '0', '', '$2a$10$gBqKUDSxjc4mHUp6Pcrp8evF1BVhgkpq8cm65iqWtHkkDP1wk/Jaa', '0', '0', '', NULL, NULL, '2024-01-04 17:22:48', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO sys_user VALUES (63, 110, '15881027005', '赵   洪', '00', '', '15881027005', '0', '', '$2a$10$HbyEXT7JR0HMv/rqi9YuQOKCyDxZg/uYgayoSOcE2.tDSVNS0OBpW', '0', '0', '', NULL, NULL, '2024-01-04 17:22:48', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO sys_user VALUES (64, 110, '18782047395', '雷情情', '00', '', '18782047395', '1', '', '$2a$10$DLeq2ePfvTS9cAarUu87LuM8d1nwJR5t/OBI3kc5nT858nIo0vpR2', '0', '0', '', NULL, NULL, '2024-01-04 17:22:48', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO sys_user VALUES (65, 110, '13668275672', '刘向东', '00', '', '13668275672', '0', '', '$2a$10$GUkGxa.u4jsBVE5mAXVTcetM0t6JIxMPUthi6v5IitkVSZUlpzf5.', '0', '0', '', NULL, NULL, '2024-01-04 17:22:48', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO sys_user VALUES (66, 110, '13880738396', '徐志勇', '00', '', '13880738396', '0', '', '$2a$10$toSkneflSQedWXrjbim6lut03gEx1HlV4FV1UFYocdtDpEhpbbLam', '0', '0', '', NULL, NULL, '2024-01-04 17:22:48', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO sys_user VALUES (67, 110, '15828108217', '李   敏', '00', '', '15828108217', '1', '', '$2a$10$c8ADHg87uPh0KaTXl.hWm.5z4hVDRtFmTprgfAJ1y.yVj27mEvV8i', '0', '0', '', NULL, NULL, '2024-01-04 17:22:48', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO sys_user VALUES (68, 110, '13689063294', '何   玲', '00', '', '13689063294', '1', '', '$2a$10$v1/ZnLyGAQwuQ7fUjy/kdeklmPo7e3uR/ogj5KmvjIPEQF7mqM/BS', '0', '0', '', NULL, NULL, '2024-01-04 17:22:48', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO sys_user VALUES (69, 110, '15982266763', '谭天宇', '00', '', '15982266763', '0', '', '$2a$10$QNa18og32fQ979WGRWGFTOLgHszwXzvE.a9dSnuqMqQ4hABt5MBRa', '0', '0', '', NULL, NULL, '2024-01-04 17:22:48', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO sys_user VALUES (70, 110, '18384964273', '李丽昕', '00', '', '18384964273', '1', '', '$2a$10$f7M7gFzNtCxjBCDZjXlvz.ROHw7vedqYtpX1BRLmT9X/5OouCXna2', '0', '0', '', NULL, NULL, '2024-01-04 17:22:48', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO sys_user VALUES (71, 110, '15108259951', '陈   波', '00', '', '15108259951', '0', '', '$2a$10$nkbLOjwcHqge.kwX4bTSWOxX6owLTazGVVrthxxPiun9zLP8NpYTW', '0', '0', '', NULL, NULL, '2024-01-04 17:22:48', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO sys_user VALUES (72, 110, '18483229925', '张   敏', '00', '', '18483229925', '1', '', '$2a$10$UodO6Pu05eUct21vfnuQIOIwHhuEw3xkmZPEFjaeP378YoiQ/86Ee', '0', '0', '', NULL, NULL, '2024-01-04 17:22:48', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO sys_user VALUES (73, 110, '15308209119', '李   磊', '00', '', '15308209119', '0', '', '$2a$10$DYNX/J5XG6CCniWthrA3KOau0kWEw8gtMSnS7dhtofuCpZLQfyRsG', '0', '0', '', NULL, NULL, '2024-01-04 17:22:48', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO sys_user VALUES (74, 110, '18190687602', '杨为康', '00', '', '18190687602', '0', '', '$2a$10$Vzo2gOmvHdI6TZxZCO2iTePU8fa9oVN6xPmyT2ZapQ2sZEJRM.tWa', '0', '0', '', NULL, NULL, '2024-01-04 17:22:48', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO sys_user VALUES (75, 110, '15202868564', '夏志斌', '00', '', '15202868564', '0', '', '$2a$10$ucCDdz5DYNZy64aKKSxH/.Lib./7T5rLGECIWXzwBLalCQk0X1fka', '0', '0', '', NULL, NULL, '2024-01-04 17:22:48', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO sys_user VALUES (76, 110, '18048613219', '刘轩庭', '00', '', '18048613219', '0', '', '$2a$10$.pSSK43SDZGc3tt1sjZREe/d0hCAbHpmUKvyFzJ1vtctvSZpdf.ka', '0', '0', '', NULL, NULL, '2024-01-04 17:22:48', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO sys_user VALUES (77, 110, '18482156612', '廖友福', '00', '', '18482156612', '0', '', '$2a$10$47nqvaqoPpAbcR9wH.ar9.nBCbKshOpTP0HwgBxsFWt3wqSaW/U0y', '0', '0', '', NULL, NULL, '2024-01-04 17:22:48', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO sys_user VALUES (78, 110, '13880417112', '潘林海', '00', '', '13880417112', '0', '', '$2a$10$z1iuKFb6q9SSiXoELcrfjuYWLnAbPorD42T.5nCEmLUXwL0/Ahe8m', '0', '0', '', NULL, NULL, '2024-01-04 17:22:48', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO sys_user VALUES (79, 110, '13518119939', '邓锡全', '00', '', '13518119939', '0', '', '$2a$10$auJq1XFdaj.2.WXKS98mxOWcprpL3LGl5h3Fd1sBwAoUfh1c6zlrK', '0', '0', '', NULL, NULL, '2024-01-04 17:22:48', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO sys_user VALUES (80, 110, '15208122776', '张   杰', '00', '', '15208122776', '0', '', '$2a$10$HcC7iiq4GR1Ca0JRrJntOemcBW3vO.tt9/EUbmvQJ9M.QIs1j6IJC', '0', '0', '', NULL, NULL, '2024-01-04 17:22:48', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO sys_user VALUES (81, 110, '17345094889', '廖   双', '00', '', '17345094889', '0', '', '$2a$10$AA3hI9GxRBB3XD9N/NthD.nqYf487wG3BvJQgYsSTublKos1Gy1Km', '0', '0', '', NULL, NULL, '2024-01-04 17:22:48', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO sys_user VALUES (82, 110, '15520996706', '廖吉兴', '00', '', '15520996706', '0', '', '$2a$10$/KNuVYgY/iKADZZg.iykyuJK/rrgi/CpbZy.ZFv3NKm4MrpqBnCFu', '0', '0', '', NULL, NULL, '2024-01-04 17:22:48', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO sys_user VALUES (83, 110, '15692823805', '王海宾', '00', '', '15692823805', '0', '', '$2a$10$OF1jB2LgFMeaakI6NTPqx.nTTe4bKzZeaP9dYccOk0v0rdCzja7Jy', '0', '0', '', NULL, NULL, '2024-01-04 17:22:48', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO sys_user VALUES (84, 111, '13540773353', '杨   振', '00', '', '13540773353', '0', '', '$2a$10$m8MnVkkjv9DT7GRaVDfG9e0lQM79NJPBwFQL3eckGh32qylKlNeky', '0', '0', '', NULL, NULL, '2024-01-04 17:22:48', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO sys_user VALUES (85, 111, '18380220140', '甘雨婷', '00', '', '18380220140', '1', '', '$2a$10$HXgw5OtU9uUCiKbSAPG0xe5PwGiZWlCIlJtltgXdtCYIZxIcKw01S', '0', '0', '', NULL, NULL, '2024-01-04 17:22:48', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO sys_user VALUES (86, 111, '13608005983', '周   强', '00', '', '13608005983', '0', '', '$2a$10$jIiDO3ighwg51nlJe4WbZet365ysf61KTuqrDNsF9YD90fHAMf9cy', '0', '0', '', NULL, NULL, '2024-01-04 17:22:48', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO sys_user VALUES (87, 111, '13540422960', '邹   霞', '00', '', '13540422960', '1', '', '$2a$10$JGmiiO3vjhEF5e2BXubE1uE/DRzpcmK3SMBZo/EDExsd8L9TWqEHm', '0', '0', '', NULL, NULL, '2024-01-04 17:22:48', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO sys_user VALUES (88, 111, '13488985627', '罗声燕', '00', '', '13488985627', '1', '', '$2a$10$.lFR.S8c/i3550O88zhk4OIyeYF2vmulknGqBvE/hi8b9id1RLNry', '0', '0', '', NULL, NULL, '2024-01-04 17:22:48', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO sys_user VALUES (89, 111, '18227609102', '王   琴', '00', '', '18227609102', '1', '', '$2a$10$hW41I3wMpnM.GiPO85jv3eyr6uJglfpj2SV/fU9etfXuBjHgIIveO', '0', '0', '', NULL, NULL, '2024-01-04 17:22:48', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO sys_user VALUES (90, 111, '15281034798', '李   静', '00', '', '15281034798', '1', '', '$2a$10$BIV.X9sgXwCLmnx0MjvbN.xnJ0d9mSv7Fe1HsB.d5UvqhYBux4aRK', '0', '0', '', NULL, NULL, '2024-01-04 17:22:48', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO sys_user VALUES (91, 111, '18380143305', '刘   垚', '00', '', '18380143305', '1', '', '$2a$10$9pXNh3pit.p.3lCv.1vIAeqm594O0y2ycUVTK5aXqbf1.DD9ckHr6', '0', '0', '', NULL, NULL, '2024-01-04 17:22:48', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO sys_user VALUES (92, 111, '15208298451', '李   杨', '00', '', '15208298451', '0', '', '$2a$10$K25fAdfUGilTZz9BHlKBnezcMkD/Pv.uJKM1H0/jn.cOOas5jDVea', '0', '0', '', NULL, NULL, '2024-01-04 17:22:48', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO sys_user VALUES (93, 111, '18990913384', '朱   姝', '00', '', '18990913384', '1', '', '$2a$10$GXcpkSxBeuM1tj66W6M50.YPQKMOccRTD64wikP5LuRW0PMhJ2Z5q', '0', '0', '', NULL, NULL, '2024-01-04 17:22:48', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO sys_user VALUES (94, 111, '18483229950', '唐   浩', '00', '', '18483229950', '0', '', '$2a$10$B..WW48a/JzGIgxdKoQEuu70YDGVmqJf/PV/WzcWjhatTZMA9Ch..', '0', '0', '', NULL, NULL, '2024-01-04 17:22:48', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO sys_user VALUES (95, 111, '15108355309', '张   韦', '00', '', '15108355309', '0', '', '$2a$10$2aepTeKqlbUhb1x6i0K88OxLlZohvIf5JZ2xhgZO8It5MagkvLHHC', '0', '0', '', NULL, NULL, '2024-01-04 17:22:48', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO sys_user VALUES (96, 111, '18108260500', '黄建春', '00', '', '18108260500', '0', '', '$2a$10$sfPuHSWY3AytrF7.o/cMAeXwb.GU1/wk4VJw4FLKgEnLNKlMdIRee', '0', '0', '', NULL, NULL, '2024-01-04 17:22:48', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO sys_user VALUES (97, 111, '13881755761', '廖绍毅', '00', '', '13881755761', '0', '', '$2a$10$g9/NOZbNS6eIcqnEg6Z2geNyQIMNJtTJrahTvIYeDis68GaQ.McJG', '0', '0', '', NULL, NULL, '2024-01-04 17:22:48', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO sys_user VALUES (98, 111, '15700353317', '杨   晶', '00', '', '15700353317', '0', '', '$2a$10$Efj2FINLArOIOgEKa3vqp.k0gpwmJKlWWlXwTrQmSIO2qsVlIWZAa', '0', '0', '', NULL, NULL, '2024-01-04 17:22:48', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO sys_user VALUES (99, 111, '13618069959', '蒋剑虹', '00', '', '13618069959', '0', '', '$2a$10$5osgmB9ZInuTYvyMUedKqe2aDJM91i/KjOxGWWCZb9WO/45U7Zok.', '0', '0', '', NULL, NULL, '2024-01-04 17:22:48', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO sys_user VALUES (100, 111, '13882487125', '赵明焱', '00', '', '13882487125', '0', '', '$2a$10$zs4QH/xd0JDuYgrftHUhRedB5SWCE.d7pdTxhUmdo/OYVxx2fSFWq', '0', '0', '', NULL, NULL, '2024-01-04 17:22:48', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO sys_user VALUES (101, 111, '18228226661', '董旭鹏', '00', '', '18228226661', '0', '', '$2a$10$yaBpFaISskiafcOa/k28VeSQSMiYhCxbtmMoXN/fruESTkMs4RwA6', '0', '0', '', NULL, NULL, '2024-01-04 17:22:48', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO sys_user VALUES (102, 111, '15775308748', '邓汶滨', '00', '', '15775308748', '0', '', '$2a$10$5L36DYl/Q.wmGKsolG/x0u4vnK78sVY59Qjx6fQA3z9n4dl62ykM.', '0', '0', '', NULL, NULL, '2024-01-04 17:22:48', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO sys_user VALUES (103, 112, '13688460154', '周   全', '00', '', '13688460154', '0', '', '$2a$10$TQMgM2lTRkeTB4YY5IHQ0.xvCGZlnd774UdWe.OPGElTkRuLAsEz6', '0', '0', '', NULL, NULL, '2024-01-04 17:22:48', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO sys_user VALUES (104, 112, '13688404696', '柏金川', '00', '', '13688404696', '0', '', '$2a$10$4ih05H.SB537jI2sHx756.hQvWBbm.4ViXs7HFKndjDQDCyvYz1rO', '0', '0', '', NULL, NULL, '2024-01-04 17:22:48', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO sys_user VALUES (105, 112, '13594658239', '黄安堂', '00', '', '13594658239', '0', '', '$2a$10$uSefDVQx.kottALOIZptjO0RnZhvITS4QTnXjSBJddqYfOftdZ8Pa', '0', '0', '', NULL, NULL, '2024-01-04 17:22:48', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO sys_user VALUES (106, 112, '13408566079', '李学勇', '00', '', '13408566079', '0', '', '$2a$10$8ru4dmjHBh21h8C3FTpdMeqsG4RHVyvqmqUFRFCDCUok2uH2ZLjiy', '0', '0', '', NULL, NULL, '2024-01-04 17:22:48', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO sys_user VALUES (107, 112, '15881283512', '陈俊恺', '00', '', '15881283512', '0', '', '$2a$10$eqX3G0LjlptoBsMefxIjXuzSEaq5opPJjzqoitrp4Dhun3u1o1F1i', '0', '0', '', NULL, NULL, '2024-01-04 17:22:48', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO sys_user VALUES (108, 112, '15883351306', '彭永红', '00', '', '15883351306', '0', '', '$2a$10$Tlq6UDINB73aeR8MCW6emOO7MHLRUGkTZ0ud/oNvTrJllwwDpxhGe', '0', '0', '', NULL, NULL, '2024-01-04 17:22:48', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO sys_user VALUES (109, 112, '18281010079', '邓   静', '00', '', '18281010079', '0', '', '$2a$10$pstdOImPwTHv54sONZEyBObA1RySMTJx2rx5btFUq6WF3qkkeP2Y6', '0', '0', '', NULL, NULL, '2024-01-04 17:22:48', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO sys_user VALUES (110, 112, '18328739381', '刘庆波', '00', '', '18328739381', '0', '', '$2a$10$p72rrc68EO/XkCYDVVTNDurHcg4z64VgyedcadnOiX7RWV2GU7pv.', '0', '0', '', NULL, NULL, '2024-01-04 17:22:48', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO sys_user VALUES (111, 112, '18205207306', '高   强', '00', '', '18205207306', '0', '', '$2a$10$p9WM4wlg34eq7yb9GAe.a.yvZhqsUBVQ.DIFIrBWZ5ufrUsu5oIKm', '0', '0', '', NULL, NULL, '2024-01-04 17:22:48', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO sys_user VALUES (112, 112, '18380411075', '韩兴国', '00', '', '18380411075', '0', '', '$2a$10$0RNiRPmnuFMvCbRsSAQ4COgX0GRbi304ZpcNuV/gzAoZFYwv1fNYS', '0', '0', '', NULL, NULL, '2024-01-04 17:22:48', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO sys_user VALUES (113, 112, '13693480782', '何   安', '00', '', '13693480782', '0', '', '$2a$10$vPcVlPiTH2nOO48/JTeXt.FpFoc9V407XxcCUmbt23Fe3pL5AvqYK', '0', '0', '', NULL, NULL, '2024-01-04 17:22:48', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO sys_user VALUES (114, 113, '18628072166', '李春生', '00', '', '18628072166', '0', '', '$2a$10$Nojkqmf0J0e2ZG/7H/RNAOLQvtoCgOB.zqf52oCXnbW7XlN6VzaOe', '0', '0', '', NULL, NULL, '2024-01-04 17:22:48', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO sys_user VALUES (115, 113, '13980688458', '段文祥', '00', '', '13980688458', '0', '', '$2a$10$4ETMsgQR7HcIjqmE3SXATOxud3L/tpPiYqt0GGRHsIB55WM4rR9Ry', '0', '0', '', NULL, NULL, '2024-01-04 17:22:48', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO sys_user VALUES (116, 113, '18980006770', '张   伟', '00', '', '18980006770', '0', '', '$2a$10$dtTx73vRXEnbuwbyt.Hm4uhDLRI07BOwgRMMx1/tZBBy9CFTb8Mw6', '0', '0', '', NULL, NULL, '2024-01-04 17:22:48', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO sys_user VALUES (117, 113, '15298033499', '万   明', '00', '', '15298033499', '0', '', '$2a$10$D9KhWl1cXJd7X8ejB8cZmODrpw.7CY0QROlXYc20zy/tyhGAbFZcW', '0', '0', '', NULL, NULL, '2024-01-04 17:22:48', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO sys_user VALUES (118, 113, '18345595350', '王雨地', '00', '', '18345595350', '0', '', '$2a$10$pwU00C244h.JM52gYAwXDemz8GD6G8QQL81ZIHHswR6owx3JJQzf2', '0', '0', '', NULL, NULL, '2024-01-04 17:22:48', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO sys_user VALUES (119, 113, '13881710080', '陈   兰', '00', '', '13881710080', '1', '', '$2a$10$sXVsn5kxi5rNd5mYJW.MrOKfY1YY/eFYYUNAm6f8A9Ak9JbF2Js0y', '0', '0', '', NULL, NULL, '2024-01-04 17:22:48', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO sys_user VALUES (120, 113, '18582552495', '张   可', '00', '', '18582552495', '0', '', '$2a$10$..LijGqYettSPi41oAdLnehfukhiYKPpI9t1EKaYhrTyuW/y.v.By', '0', '0', '', NULL, NULL, '2024-01-04 17:22:48', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO sys_user VALUES (121, 114, '13551823637', '李   锋', '00', '', '13551823637', '0', '', '$2a$10$/T1kLMSSFMAmoy4QhkTzFO1vVm8/csHuuaeAKsjeEx/w1d3SsA2pi', '0', '0', '', NULL, NULL, '2024-01-04 17:22:48', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO sys_user VALUES (122, 114, '13881397406', '张元锋', '00', '', '13881397406', '0', '', '$2a$10$3L/5ASJal42wccw7BhyIaOcedcj6IOadjnUGymzWH/kbYYQmA/K3y', '0', '0', '', NULL, NULL, '2024-01-04 17:22:48', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO sys_user VALUES (123, 114, '18602865330', '钱俊锦', '00', '', '18602865330', '0', '', '$2a$10$YuF2Yk6rCdCIu0c5Q6Uw4eBdh3vcTmbCpmETgd.FI.RVUVL.uTLEq', '0', '0', '', NULL, NULL, '2024-01-04 17:22:48', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO sys_user VALUES (124, 114, '17311677347', '陈   伟', '00', '', '17311677347', '0', '', '$2a$10$fbrbmyWNFA7aiCbOtCqaDONw7qDgdS4UZDS95BUOHJ88eUzVtr3/S', '0', '0', '', NULL, NULL, '2024-01-04 17:22:48', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO sys_user VALUES (125, 114, '13628057328', '薛   帅', '00', '', '13628057328', '0', '', '$2a$10$ND.pJthbdY1tY8LHYtJkpeADmaTDJNvwPClaERSAyKIcLd4xT5uyq', '0', '0', '', NULL, NULL, '2024-01-04 17:22:48', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO sys_user VALUES (126, 114, '18482173451', '冉凉南', '00', '', '18482173451', '0', '', '$2a$10$IyIeQtlKtZTNpidzX4R.7OOWt21XkMBiHZn92F/f8oT94QfMUKoA6', '0', '0', '', NULL, NULL, '2024-01-04 17:22:48', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO sys_user VALUES (127, 114, '18382319155', '谢承东', '00', '', '18382319155', '0', '', '$2a$10$AkWugwBKCG7oKIKPIn9mBOaFtuCtTw3cJvz78ryEMUTTjfG/fDYgy', '0', '0', '', NULL, NULL, '2024-01-04 17:22:48', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO sys_user VALUES (128, 114, '18227480379', '周   炎', '00', '', '18227480379', '0', '', '$2a$10$5e7lOXqGekSSu.rKKMQJYuLJc68RZllH2ebGFEr/He6cc2zsQJPzm', '0', '0', '', NULL, NULL, '2024-01-04 17:22:48', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO sys_user VALUES (129, 114, '18140430240', '胡   庆', '00', '', '18140430240', '0', '', '$2a$10$IckBbWNu8BS6JkdITuvMzu7G/Ztl.d.gbp1xwQqpgYDUEYEaxFUkS', '0', '0', '', NULL, NULL, '2024-01-04 17:22:48', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO sys_user VALUES (130, 114, '18780029464', '何   行', '00', '', '18780029464', '0', '', '$2a$10$0BpGvlJOqHQyM//wJh3lAO/7e/s.dys5iVCGu0K/qcjsLpgveK4ou', '0', '0', '', NULL, NULL, '2024-01-04 17:22:48', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO sys_user VALUES (131, 103, '18283500919', '杨良轩', '00', '', '18283500919', '0', '', '$2a$10$vUYbhAPQRZuj8S5cjvC5XODjTswaxbWr049ICezchhb4ueoNQ4S6i', '0', '0', '', NULL, NULL, '2024-01-04 17:22:48', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO sys_user VALUES (132, 103, '13880159142', '周建伟', '00', '', '13880159142', '0', '', '$2a$10$vY871WQd/F9BGNg1Ki2.VOYsT704ttmif5b3U1Aaj392CydaVTTfm', '0', '0', '', NULL, NULL, '2024-01-04 17:22:48', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO sys_user VALUES (133, 103, '13980809722', '罗友权', '00', '', '13980809722', '0', '', '$2a$10$/cL8xD1pFmFxLyehpr2x1e3n/8KqKG6lWaXdjyHyaZo37oCP4wfem', '0', '0', '', NULL, NULL, '2024-01-04 17:22:48', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO sys_user VALUES (134, 103, '15228916534', '凌   涛', '00', '', '15228916534', '0', '', '$2a$10$BdjU17zPn5JZpcyOBBK3X.GiQOdZfuRVmiljOJMde4/EJM67Zp7/C', '0', '0', '', NULL, NULL, '2024-01-04 17:22:48', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO sys_user VALUES (135, 103, '15928517280', '雷光泽', '00', '', '15928517280', '0', '', '$2a$10$soo68IbKDhCT0mhj.j0Nou2rsgVxLU78BsowMo7ZorasQj9FPf2OG', '0', '0', '', NULL, NULL, '2024-01-04 17:22:48', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO sys_user VALUES (136, 103, '15828156243', '廖   勇', '00', '', '15828156243', '0', '', '$2a$10$9QO6qXNSAiAtWFCXbvEeu.pHoBLHZig5ra.y2ZNRyRDxL0W4WU2Q2', '0', '0', '', NULL, NULL, '2024-01-04 17:22:48', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO sys_user VALUES (137, 103, '14726050305', '康科伟', '00', '', '14726050305', '0', '', '$2a$10$04.7zNYdTwXzlQ8J0SYNaOZMc.iarm2gBeD37na6.aAtuBzfnpnUO', '0', '0', '', NULL, NULL, '2024-01-04 17:22:48', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO sys_user VALUES (138, 103, '18111675896', '熊艳华', '00', '', '18111675896', '0', '', '$2a$10$uLfMqz3YfEuAO8TI0XOzE.Xn0FZA7U6zrfss6Xp.anF4xUZNXT37y', '0', '0', '', NULL, NULL, '2024-01-04 17:22:48', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO sys_user VALUES (139, 103, '18982085285', '赵永来', '00', '', '18982085285', '0', '', '$2a$10$TzKjV2T1FJ7YubxeIZZnmuLBsdppYlHoxruXCh0aBhHyV/yLGaiai', '0', '0', '', NULL, NULL, '2024-01-04 17:22:48', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO sys_user VALUES (140, 115, '15982167611', '刘   洋', '00', '', '15982167611', '0', '', '$2a$10$qxB0MTpLA7WzUhBpQlrC5u.7JymKt2bwAJ9gupwWQeKcANtov0qn.', '0', '0', '', NULL, NULL, '2024-01-04 17:22:48', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO sys_user VALUES (141, 115, '17345090038', '郑   鹏', '00', '', '17345090038', '0', '', '$2a$10$meTOhyDbWqzhrzCFDGM3hu.cOFwinewDE1Jp3YYR/ThYBvOssce7G', '0', '0', '', NULL, NULL, '2024-01-04 17:22:48', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO sys_user VALUES (142, 115, '17612894797', '黄   强', '00', '', '17612894797', '0', '', '$2a$10$JyofvRfiRj5Ug2G4ux00eOtMvQSOKu.tjo0.Juey2xMZSsAggVE76', '0', '0', '', NULL, NULL, '2024-01-04 17:22:48', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO sys_user VALUES (143, 116, '13980977233', '李   禺', '00', '', '13980977233', '0', '', '$2a$10$AiciBrz84EwU3G3KxW9bCOZXgxraa74RRzAvyetSEjC30Zvq2ooH2', '0', '0', '', NULL, NULL, '2024-01-04 17:22:48', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO sys_user VALUES (144, 116, '18602830814', '黄梅琳', '00', '', '18602830814', '1', '', '$2a$10$Ij6SqoLMDrpLBJ87rKqIh.8JDRNMROQQyHQSZV5wsUn7ybJ53ip86', '0', '0', '', NULL, NULL, '2024-01-04 17:22:48', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO sys_user VALUES (145, 116, '13488982667', '尹   超', '00', '', '13488982667', '0', '', '$2a$10$F.REC7OQ2uNCFeUOpopqaeSsDn9MR/a01G4TTG.uaCgq2OukjBXrO', '0', '0', '', NULL, NULL, '2024-01-04 17:22:48', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO sys_user VALUES (146, 116, '15881108097', '程   昊', '00', '', '15881108097', '0', '', '$2a$10$y1Z2H5Wp4yhdnmHcNO7U6u9108qE/uxqQ7OVumAtVLlgDbj/ZWo/.', '0', '0', '', NULL, NULL, '2024-01-04 17:22:48', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO sys_user VALUES (147, 116, '15928663470', '丁   亮', '00', '', '15928663470', '0', '', '$2a$10$WYBOgIm.Y.LNSEKs3VPaX.1JpD.VLodHuug5wOeX636vln31SHII2', '0', '0', '', NULL, NULL, '2024-01-04 17:22:48', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO sys_user VALUES (148, 117, '13880644169', '林方迁', '00', '', '13880644169', '0', '', '$2a$10$VPrToUrklp3J3NtnHAy7VulN9Eck4eTuII4xmXh.JKOue9BN91Tq.', '0', '0', '', NULL, NULL, '2024-01-04 17:22:48', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO sys_user VALUES (149, 117, '18140055216', '杨   柳', '00', '', '18140055216', '1', '', '$2a$10$K1WECO/2G5tAKCr3h16CzeypD2CSVjq1MWdk1FLjhnAKD2SwanrT6', '0', '0', '', NULL, NULL, '2024-01-04 17:22:48', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);


-- ----------------------------
-- 3、岗位信息表
-- ----------------------------
drop table if exists sys_post;
create table sys_post
(
  post_id       bigint(20)      not null auto_increment    comment '岗位ID',
  post_code     varchar(64)     not null                   comment '岗位编码',
  post_name     varchar(50)     not null                   comment '岗位名称',
  post_sort     int(4)          not null                   comment '显示顺序',
  status        char(1)         not null                   comment '状态（0正常 1停用）',
  create_by     varchar(64)     default ''                 comment '创建者',
  create_time   datetime                                   comment '创建时间',
  update_by     varchar(64)     default ''			       comment '更新者',
  update_time   datetime                                   comment '更新时间',
  remark        varchar(500)    default null               comment '备注',
  primary key (post_id)
) engine=innodb comment = '岗位信息表';

-- ----------------------------
-- 初始化-岗位信息表数据
-- ----------------------------
INSERT INTO sys_post VALUES (1, '1', '董事长', 1, '0', 'admin', '2024-01-04 14:21:52', NULL, NULL, NULL);
INSERT INTO sys_post VALUES (2, '2', '总经理', 2, '0', 'admin', '2024-01-04 14:22:52', NULL, NULL, NULL);
INSERT INTO sys_post VALUES (3, '3', '董事', 3, '0', 'admin', '2024-01-04 14:32:11', NULL, NULL, NULL);
INSERT INTO sys_post VALUES (4, '4', '总支书记', 4, '0', 'admin', '2024-01-04 14:34:43', NULL, NULL, NULL);
INSERT INTO sys_post VALUES (5, '5', '高级顾问', 5, '0', 'admin', '2024-01-04 14:35:34', NULL, NULL, NULL);
INSERT INTO sys_post VALUES (6, '6', '副总经理', 6, '0', 'admin', '2024-01-04 14:35:48', NULL, NULL, NULL);
INSERT INTO sys_post VALUES (7, '7', '秘书', 7, '0', 'admin', '2024-01-04 14:36:08', NULL, NULL, NULL);
INSERT INTO sys_post VALUES (8, '8', '总支干事', 8, '0', 'admin', '2024-01-04 14:37:29', NULL, NULL, NULL);
INSERT INTO sys_post VALUES (9, '9', '总工程师', 9, '0', 'admin', '2024-01-04 14:37:43', NULL, NULL, NULL);
INSERT INTO sys_post VALUES (10, '10', '总经理助理', 10, '0', 'admin', '2024-01-04 14:38:00', NULL, NULL, NULL);
INSERT INTO sys_post VALUES (11, '11', '副总工程师', 11, '0', 'admin', '2024-01-04 14:42:07', NULL, NULL, NULL);
INSERT INTO sys_post VALUES (12, '12', '主任', 12, '0', 'admin', '2024-01-04 14:39:20', NULL, NULL, NULL);
INSERT INTO sys_post VALUES (13, '13', '副主任', 13, '0', 'admin', '2024-01-04 14:39:34', NULL, NULL, NULL);
INSERT INTO sys_post VALUES (14, '14', '专总', 14, '0', 'admin', '2024-01-04 14:40:44', NULL, NULL, NULL);
INSERT INTO sys_post VALUES (15, '15', '经理', 15, '0', 'admin', '2024-01-04 14:48:57', NULL, NULL, NULL);
INSERT INTO sys_post VALUES (16, '16', '副经理', 16, '0', 'admin', '2024-01-04 16:50:16', '', NULL, NULL);
INSERT INTO sys_post VALUES (17, '17', '项目主任', 17, '0', 'admin', '2024-01-04 16:49:08', '', NULL, NULL);
INSERT INTO sys_post VALUES (18, '18', '项目副主任', 18, '0', 'admin', '2024-01-04 16:49:58', '', NULL, NULL);
INSERT INTO sys_post VALUES (19, '19', '专职安全员', 19, '0', 'admin', '2024-01-04 15:32:52', '', NULL, NULL);
INSERT INTO sys_post VALUES (20, '20', '工会干事', 20, '0', 'admin', '2024-01-04 14:49:48', NULL, NULL, NULL);
INSERT INTO sys_post VALUES (21, '21', '业务主管', 21, '0', 'admin', '2024-01-04 14:50:20', NULL, NULL, NULL);
INSERT INTO sys_post VALUES (22, '22', '业务助理', 22, '0', 'admin', '2024-01-04 14:51:41', NULL, NULL, NULL);
INSERT INTO sys_post VALUES (23, '23', '文秘、办事员', 23, '0', 'admin', '2024-01-04 14:52:29', NULL, NULL, NULL);
INSERT INTO sys_post VALUES (24, '24', '会计', 24, '0', 'admin', '2024-01-04 14:53:13', NULL, NULL, NULL);
INSERT INTO sys_post VALUES (25, '25', '出纳', 25, '0', 'admin', '2024-01-04 14:53:27', NULL, NULL, NULL);
INSERT INTO sys_post VALUES (26, '26', '员工', 26, '0', 'admin', '2024-01-04 14:53:34', NULL, NULL, NULL);
INSERT INTO sys_post VALUES (27, '27', '驾驶员', 27, '0', 'admin', '2024-01-04 14:53:50', NULL, NULL, NULL);


-- ----------------------------
-- 9、用户与岗位关联表  用户1-N岗位
-- ----------------------------
drop table if exists sys_user_post;
create table sys_user_post
(
  user_id   bigint(20) not null comment '用户ID',
  post_id   bigint(20) not null comment '岗位ID',
  primary key (user_id, post_id)
) engine=innodb comment = '用户与岗位关联表';

-- ----------------------------
-- 初始化-用户与岗位关联表数据
-- ----------------------------
INSERT INTO sys_user_post VALUES (1, 1);
INSERT INTO sys_user_post VALUES (2, 1);
INSERT INTO sys_user_post VALUES (2, 2);
INSERT INTO sys_user_post VALUES (3, 3);
INSERT INTO sys_user_post VALUES (4, 4);
INSERT INTO sys_user_post VALUES (5, 5);
INSERT INTO sys_user_post VALUES (6, 5);
INSERT INTO sys_user_post VALUES (7, 6);
INSERT INTO sys_user_post VALUES (8, 7);
INSERT INTO sys_user_post VALUES (8, 8);
INSERT INTO sys_user_post VALUES (8, 12);
INSERT INTO sys_user_post VALUES (9, 9);
INSERT INTO sys_user_post VALUES (10, 6);
INSERT INTO sys_user_post VALUES (11, 6);
INSERT INTO sys_user_post VALUES (12, 6);
INSERT INTO sys_user_post VALUES (13, 10);
INSERT INTO sys_user_post VALUES (13, 12);
INSERT INTO sys_user_post VALUES (14, 10);
INSERT INTO sys_user_post VALUES (14, 12);
INSERT INTO sys_user_post VALUES (15, 19);
INSERT INTO sys_user_post VALUES (16, 23);
INSERT INTO sys_user_post VALUES (17, 23);
INSERT INTO sys_user_post VALUES (18, 23);
INSERT INTO sys_user_post VALUES (19, 23);
INSERT INTO sys_user_post VALUES (20, 13);
INSERT INTO sys_user_post VALUES (21, 13);
INSERT INTO sys_user_post VALUES (22, 20);
INSERT INTO sys_user_post VALUES (22, 23);
INSERT INTO sys_user_post VALUES (23, 23);
INSERT INTO sys_user_post VALUES (24, 23);
INSERT INTO sys_user_post VALUES (25, 23);
INSERT INTO sys_user_post VALUES (26, 23);
INSERT INTO sys_user_post VALUES (27, 23);
INSERT INTO sys_user_post VALUES (28, 25);
INSERT INTO sys_user_post VALUES (29, 24);
INSERT INTO sys_user_post VALUES (30, 24);
INSERT INTO sys_user_post VALUES (31, 25);
INSERT INTO sys_user_post VALUES (32, 12);
INSERT INTO sys_user_post VALUES (33, 13);
INSERT INTO sys_user_post VALUES (34, 11);
INSERT INTO sys_user_post VALUES (35, 21);
INSERT INTO sys_user_post VALUES (36, 21);
INSERT INTO sys_user_post VALUES (37, 23);
INSERT INTO sys_user_post VALUES (38, 21);
INSERT INTO sys_user_post VALUES (39, 12);
INSERT INTO sys_user_post VALUES (40, 13);
INSERT INTO sys_user_post VALUES (41, 26);
INSERT INTO sys_user_post VALUES (42, 26);
INSERT INTO sys_user_post VALUES (43, 26);
INSERT INTO sys_user_post VALUES (44, 26);
INSERT INTO sys_user_post VALUES (45, 12);
INSERT INTO sys_user_post VALUES (46, 26);
INSERT INTO sys_user_post VALUES (47, 26);
INSERT INTO sys_user_post VALUES (48, 26);
INSERT INTO sys_user_post VALUES (49, 26);
INSERT INTO sys_user_post VALUES (50, 26);
INSERT INTO sys_user_post VALUES (51, 26);
INSERT INTO sys_user_post VALUES (52, 11);
INSERT INTO sys_user_post VALUES (52, 12);
INSERT INTO sys_user_post VALUES (53, 11);
INSERT INTO sys_user_post VALUES (54, 11);
INSERT INTO sys_user_post VALUES (55, 14);
INSERT INTO sys_user_post VALUES (56, 14);
INSERT INTO sys_user_post VALUES (57, 26);
INSERT INTO sys_user_post VALUES (58, 26);
INSERT INTO sys_user_post VALUES (59, 26);
INSERT INTO sys_user_post VALUES (60, 26);
INSERT INTO sys_user_post VALUES (61, 26);
INSERT INTO sys_user_post VALUES (62, 26);
INSERT INTO sys_user_post VALUES (63, 13);
INSERT INTO sys_user_post VALUES (64, 13);
INSERT INTO sys_user_post VALUES (65, 26);
INSERT INTO sys_user_post VALUES (66, 26);
INSERT INTO sys_user_post VALUES (67, 26);
INSERT INTO sys_user_post VALUES (68, 26);
INSERT INTO sys_user_post VALUES (69, 26);
INSERT INTO sys_user_post VALUES (70, 26);
INSERT INTO sys_user_post VALUES (71, 26);
INSERT INTO sys_user_post VALUES (72, 26);
INSERT INTO sys_user_post VALUES (73, 26);
INSERT INTO sys_user_post VALUES (74, 26);
INSERT INTO sys_user_post VALUES (75, 26);
INSERT INTO sys_user_post VALUES (76, 26);
INSERT INTO sys_user_post VALUES (77, 26);
INSERT INTO sys_user_post VALUES (78, 26);
INSERT INTO sys_user_post VALUES (79, 26);
INSERT INTO sys_user_post VALUES (80, 26);
INSERT INTO sys_user_post VALUES (81, 26);
INSERT INTO sys_user_post VALUES (82, 26);
INSERT INTO sys_user_post VALUES (83, 26);
INSERT INTO sys_user_post VALUES (84, 12);
INSERT INTO sys_user_post VALUES (85, 13);
INSERT INTO sys_user_post VALUES (86, 26);
INSERT INTO sys_user_post VALUES (87, 26);
INSERT INTO sys_user_post VALUES (88, 26);
INSERT INTO sys_user_post VALUES (89, 26);
INSERT INTO sys_user_post VALUES (90, 26);
INSERT INTO sys_user_post VALUES (91, 26);
INSERT INTO sys_user_post VALUES (92, 26);
INSERT INTO sys_user_post VALUES (93, 26);
INSERT INTO sys_user_post VALUES (94, 26);
INSERT INTO sys_user_post VALUES (95, 26);
INSERT INTO sys_user_post VALUES (96, 26);
INSERT INTO sys_user_post VALUES (97, 26);
INSERT INTO sys_user_post VALUES (98, 26);
INSERT INTO sys_user_post VALUES (99, 26);
INSERT INTO sys_user_post VALUES (100, 26);
INSERT INTO sys_user_post VALUES (101, 26);
INSERT INTO sys_user_post VALUES (102, 26);
INSERT INTO sys_user_post VALUES (103, 12);
INSERT INTO sys_user_post VALUES (104, 13);
INSERT INTO sys_user_post VALUES (105, 26);
INSERT INTO sys_user_post VALUES (106, 26);
INSERT INTO sys_user_post VALUES (107, 26);
INSERT INTO sys_user_post VALUES (108, 26);
INSERT INTO sys_user_post VALUES (109, 26);
INSERT INTO sys_user_post VALUES (110, 26);
INSERT INTO sys_user_post VALUES (111, 26);
INSERT INTO sys_user_post VALUES (112, 26);
INSERT INTO sys_user_post VALUES (113, 26);
INSERT INTO sys_user_post VALUES (114, 15);
INSERT INTO sys_user_post VALUES (115, 26);
INSERT INTO sys_user_post VALUES (116, 26);
INSERT INTO sys_user_post VALUES (117, 26);
INSERT INTO sys_user_post VALUES (118, 26);
INSERT INTO sys_user_post VALUES (119, 26);
INSERT INTO sys_user_post VALUES (120, 26);
INSERT INTO sys_user_post VALUES (121, 17);
INSERT INTO sys_user_post VALUES (122, 17);
INSERT INTO sys_user_post VALUES (123, 18);
INSERT INTO sys_user_post VALUES (124, 26);
INSERT INTO sys_user_post VALUES (125, 26);
INSERT INTO sys_user_post VALUES (126, 26);
INSERT INTO sys_user_post VALUES (127, 26);
INSERT INTO sys_user_post VALUES (128, 26);
INSERT INTO sys_user_post VALUES (129, 26);
INSERT INTO sys_user_post VALUES (130, 26);
INSERT INTO sys_user_post VALUES (131, 27);
INSERT INTO sys_user_post VALUES (132, 27);
INSERT INTO sys_user_post VALUES (133, 27);
INSERT INTO sys_user_post VALUES (134, 27);
INSERT INTO sys_user_post VALUES (135, 27);
INSERT INTO sys_user_post VALUES (136, 27);
INSERT INTO sys_user_post VALUES (137, 27);
INSERT INTO sys_user_post VALUES (138, 27);
INSERT INTO sys_user_post VALUES (139, 27);
INSERT INTO sys_user_post VALUES (140, 16);
INSERT INTO sys_user_post VALUES (141, 26);
INSERT INTO sys_user_post VALUES (142, 26);
INSERT INTO sys_user_post VALUES (143, 1);
INSERT INTO sys_user_post VALUES (144, 2);
INSERT INTO sys_user_post VALUES (145, 26);
INSERT INTO sys_user_post VALUES (146, 26);
INSERT INTO sys_user_post VALUES (147, 26);
INSERT INTO sys_user_post VALUES (148, 26);
INSERT INTO sys_user_post VALUES (149, 26);


-- ----------------------------
-- 20、cmc考核表
-- ----------------------------
drop table if exists cmc_assess;
create table cmc_assess (
  assess_id				char(19)		not null		comment '总考核表id',
  user_id				bigint			default null	comment '用户id',
  project_id			bigint			default null	comment '项目id',
  assess_time			datetime		default null	comment '考核时间（月份）',
  dept_assessment		char(1)			default null	comment '部门评核等级（不合格、合格、良好、优秀）',
  dept_advice			varchar(255)	default null	comment '部门评核意见',
  dept_time				datetime		default null	comment '部门评核时间',
  dept_assesser			varchar(30)		default null	comment '部门评核负责人',
  manager_assessment	char(1)			default null	comment '分管评核等级（不合格、合格、良好、优秀）',
  manager_advice		varchar(255)	default null	comment '分管评核意见',
  manager_time			datetime		default null	comment '分管评核时间',
  manager_assesser		varchar(30)		default null	comment '分管评核负责人',
  self_assess			varchar(255)	default null	comment '自述',
  fill_time				datetime		default null	comment '考核填报时间',
  PRIMARY KEY (assess_id)
) engine=innodb	comment = 'cmc考核表';


-- ----------------------------
-- 21、cmc考核内容表
-- ----------------------------
drop table if exists cmc_assess_content;
create table cmc_assess_content (
  content_id			char(21)		not null		comment '考核内容id(总考核表id+2位)',
  role					char(2)			default null	comment '承担角色',
  familiar				char(1)			default null	comment '熟练程度（生疏、熟练、精通）',
  remark				varchar(255)	default null	comment '备注',
  workload				char(1)			default null	comment '工作量（较少、正常、较多）',
  skill					char(1)			default null	comment '技能掌握（生疏、较熟练、熟练）',
  quality				char(1)			default null	comment '产品质量（不合格、合格、优良）',
  assessment			char(1)			default null	comment '岗位表现（不合格、合格、优良）',
  advice				varchar(255)	default null	comment '考核建议',
  PRIMARY KEY (content_id)
) engine=innodb	comment = 'cmc考核内容表';


-- ----------------------------
-- 22、cmc考核工作内容表
-- ----------------------------
drop table if exists cmc_assess_content_work;
create table cmc_assess_content_work (
  work_id				char(23)		not null		comment '工作内容id(考核内容id+2位)',
  work_count			int				default null	comment '工作项数',
  work_load				varchar(255)	default null	comment '工作量',
  PRIMARY KEY (work_id)
) engine=innodb	comment = 'cmc考核工作内容表';